@@ -98,7 +98,8 @@ NumericMatrix c_score_graf_schmid(NumericVector truth, NumericVector unique_time
 
 // [[Rcpp::export]]
 NumericMatrix c_weight_survival_score(NumericMatrix score, NumericMatrix truth,
-                                    NumericVector unique_times, NumericMatrix cens){
+                                      NumericVector unique_times, NumericMatrix cens,
+                                      bool proper, double eps){
   NumericVector times = truth(_,0);
   NumericVector status = truth(_,1);
 
@@ -113,9 +114,15 @@ NumericMatrix c_weight_survival_score(NumericMatrix score, NumericMatrix truth,
 
   for (int i = 0; i < nr; i++) {
     k = 0;
+    // if censored and proper then zero-out and remove
+    if (proper && status[i] == 0) {
+      mat(i, _) = NumericVector(nc);
+      continue;
+    }
+
     for (int j = 0; j < nc; j++) {
-      // if alive weight by true time
-      if(times[i] > unique_times[j]) {
+      // if alive and not proper then IPC weights are current time
+      if ((times[i] > unique_times[j]) && !proper) {
         for (int l = 0; l < cens_times.length(); l++) {
           if(unique_times[j] >= cens_times[l] &&
              (unique_times[j] < cens_times[l+1]  || l == cens_times.length()-1)) {
@@ -123,23 +130,34 @@ NumericMatrix c_weight_survival_score(NumericMatrix score, NumericMatrix truth,
             break;
           }
         }
-        // if dead weight by death time
+        // if dead (or alive and proper) weight by event time
+        // if censored remove
       } else {
+        if (status[i] == 0) {
+          mat(i, j) = 0;
+          continue;
+        }
+
         if (k == 0) {
           for (int l = 0; l < cens_times.length(); l++) {
-            if(times[i] >= cens_times[l] &&
+            // weight 1 if death occurs before first censoring time
+            if ((times[i] < cens_times[l]) && l == 0) {
+              k = 1;
+              break;
+            } else if(times[i] >= cens_times[l] &&
                (times[i] < cens_times[l+1] || l == cens_times.length()-1)) {
               k = cens_surv[l];
-              // k == 0 only if last obsv censored, therefore set to 0 anyway
+              // k == 0 only if last obsv censored, therefore mat is set to 0 anyway
               if(k == 0) {
-                k = 1;
+                k = eps;
               }
               break;
             }
           }
         }
 
-        mat(i, j) = (score(i, j) / k) * status[i];
+        // weight by IPCW
+        mat(i, j) = score(i, j) / k;
       }
     }
   }
@@ -249,6 +267,3 @@ float c_gonen(NumericVector crank, float tiex) {
 
   return (2 * ghci)/(n * (n - 1));
 }
-
-
-
